
#include "includes.h"             // inclus l'ensemble des classes utiles

#define CONSOLE

/**************************************************
 * definition des capteurs (pin, nom) en pull_up
 ***************************************************/

capteur CDG1(3,"Dde voie1 gauche");         
capteur CFG1(5,"Fermeture voie1 gauche");
capteur CFD1(7,"Fermeture voie1 droite");
capteur CDD1(A1,"Dde voie1 droite");
capteur CDG2(4,"Dde voie2 gauche");
capteur CFG2(6,"Fermeture voie2 gauche");
capteur CFD2(8,"Fermeture voie2 droite");
capteur CDD2(A0,"Dde voie2 droite");

/***********************************************************
 * definition des zones de detection (nom)
 ***********************************************************/
 
zone zone1GaucheDde("demande Gauche");
zone zone1GaucheFerme("fermeture Gauche");
zone zone1DroiteDde("demande Droite");
zone zone1DroiteFerme("fermeture Droite");
zone zone2GaucheDde("demande Gauche");
zone zone2GaucheFerme("fermeture Gauche");
zone zone2DroiteDde("demande Droite");
zone zone2DroiteFerme("fermeture Droite");
/************************************************
 * instances de voie tranversant le passage
 ******************************************************/
voie voie1; 
voie voie2;

/**********************************************************
 * les différents types de barrieres
 * n'en garder qu'une
 ***********************************************************/
 
/*********************************************************
 * definition de la barriere a relais (pin ouvre, pin ferme,cde,delai activation)
 *********************************************************/
 
relais cdeRelais(A2,A3,LOW,5000);    // HIGH : relais active au plus, LOW : relais active au moins

/***********************************************************************
 * definition de la barriere a bobines (pin ouvre, pin ferme, cde, delai activation) 
 **********************************************************************************/

 bobine cdeBobines(A2,A3,LOW,500,4000);    // HIGH : bobine active au plus, LOW : bobine active au moins

/***********************************************************************
 * definition de la barriere a moteur pas a pas (les 4 pins, ouverture en degre, vitesse de deplacement en us) 
 **********************************************************************************/

 pas_a_pas cdeSteps(A2,A3,A4,A5,90,5000);    

/*****************************************************************************
 * definition de la barriere avec un ou deux servos 
 * (servo1, pin servo1, duree basse PWM, duree haute PWM, pas, delai activation servo)
 * (servo1, pin servo1, servo2, pin servo2, duree basse PWM, duree haute PWM, pas, delai activation servo)
 *********************************************************************************/

Servo servo1;
Servo servo2;
servomoteur cdeServos(servo1,A2,servo2,A3,1000,2000,20,75);

/***********************************************************
 * definition des feux (pin, cde, pas du fading)  // pas = 10 par défaut
 *************************************************************/
 
feux fanal(9, LOW, 10);         // high : actif au plus, LOW actif au moins

/**********************************************************
 * definition du passage a niveau (barriere,feux,nom)
 * choisir ici le type de barrieres
 ********************************************************/
 
passage PAN(cdeRelais,fanal,"PN Locoduino");

/******************************************************
 * definition des elements du TCO
 ***********************************************************/

int pinLed = 12;          // état du passage a niveau
int pinLedTriage = 10;
int pinSwitchTriage = 11;       // switch du mode triage

// pour le reset mettre une résistance de 1K sur la pin RST et mettre a la masse pour le reset

/*********************************************************************
 * SETUP
 ********************************************************************/
 
void setup() {
  
 /************************************************************************
  * affectation des capteurs aux zones de detection
  **************************************************************************/
  
  zone1GaucheDde.add(CDG1);zone1GaucheFerme.add(CFG1);zone1DroiteDde.add(CDD1);zone1DroiteFerme.add(CFD1);
  zone2GaucheDde.add(CDG2);zone2GaucheFerme.add(CFG2);zone2DroiteDde.add(CDD2);zone2DroiteFerme.add(CFD2);

  /******************************************************************
   * affection des zones aux voies
   ************************************************************************/
   
 voie1.config(zone1GaucheDde,zone1GaucheFerme,zone1DroiteDde,zone1DroiteFerme,"voie1");
 voie2.config(zone2GaucheDde,zone2GaucheFerme,zone2DroiteDde,zone2DroiteFerme,"voie2");

/*******************************************************************
 * affectation des voies au passage a niveau
 **************************************************************************/

  PAN.add(voie1);PAN.add(voie2);

  /********************************************************
   * attachement du tco au passage a niveau
   * leds temoins et switch de triage en pull_up
   *************************************************************/

   PAN.addLed(pinLed,LOW);                  // HIGH : actif au plus, LOW : actif au moins
   PAN.addTriage(pinSwitchTriage, pinLedTriage, LOW); 

/********************************************************************
* si utilisation de servo, attachement des servos
*******************************************************************/
   
  servo1.attach(A1);
  servo2.attach(A2);
   
/***************************************************
 * affichage de la configuration
 ******************************************************/
 
 #ifdef CONSOLE
  Serial.begin(9600);   // la console
  PAN.print();
 #endif
}

/************************************************************
 * BOUCLE
 ***************************************************************/
void loop() {
  
  PAN.Loop(); // on boucle sur le passage a niveau

}
